# caerus

[![Python](https://img.shields.io/pypi/pyversions/caerus)](https://img.shields.io/pypi/pyversions/caerus)
[![PyPI Version](https://img.shields.io/pypi/v/caerus)](https://pypi.org/project/caerus/)
[![License](https://img.shields.io/badge/license-MIT-green.svg)](https://github.com/erdogant/caerus/blob/master/LICENSE)
[![Downloads](https://pepy.tech/badge/caerus)](https://pepy.tech/project/caerus)
[![Downloads](https://pepy.tech/badge/caerus/month)](https://pepy.tech/project/caerus/month)
[![Sphinx](https://img.shields.io/badge/Sphinx-Docs-Green)](https://erdogant.github.io/caerus/)
<!---[![BuyMeCoffee](https://img.shields.io/badge/buymea-coffee-yellow.svg)](https://www.buymeacoffee.com/erdogant)-->
<!---[![Coffee](https://img.shields.io/badge/coffee-black-grey.svg)](https://erdogant.github.io/donate/?currency=USD&amount=5)-->

``caerus`` is Python package to compute the local-minima with the corresponding local-maxima within the given time-frame. This approach is designed to for stock-market valley and peak detection.

Here are just a few of the things that caerus does well:
    - Ouput contains detected start-stop regions of local minima and maxima.
    - Figures are created.
    - Parameter gridsearch.
    - Designed for the detection of complex trend movements.
    
# 
**⭐️ Star this repo if you like it ⭐️**
#

#### Install caerus from PyPI

```bash
pip install caerus
```

#### Import caerus package

```python
from caerus import caerus
```
# 


### [Documentation pages](https://erdogant.github.io/caerus/)

On the [documentation pages](https://erdogant.github.io/caerus/) you can find detailed information about the working of the ``caerus`` with examples. 

<hr> 

### Examples

# 

* [Example: Detect peak and valleys in Bitcoin](https://erdogant.github.io/caerus/pages/html/Examples.html)

<p align="left">
  <a href="https://erdogant.github.io/caerus/pages/html/Examples.html">
  <img src="https://github.com/erdogant/caerus/blob/master/docs/figs/figure_btc.png" width="600" />
  <img src="https://github.com/erdogant/caerus/blob/master/docs/figs/figure_btc_last_300days.png" width="600" />
  </a>
</p>


# 

* [Example: Detect peak and valleys in Facebook](https://erdogant.github.io/caerus/pages/html/Examples.html)

<p align="left">
  <a href="https://erdogant.github.io/caerus/pages/html/Examples.html">
  <img src="https://github.com/erdogant/caerus/blob/master/docs/figs/figure_fb.png" width="600" />
  </a>
</p>


* [Example: Gridsearch](https://erdogant.github.io/caerus/pages/html/Examples.html#gridsearch)

<p align="left">
  <a href="https://erdogant.github.io/caerus/pages/html/Examples.html#gridsearch">
  <img src="https://github.com/erdogant/caerus/blob/master/docs/figs/figure_gridsearch_btc.png" width="600" />
  </a>
</p>


<hr>

### References
* https://en.wikipedia.org/wiki/Multi-armed_bandit
   
### Maintainers
* Erdogan Taskesen, github: [erdogant](https://github.com/erdogant)

### Contribute
* All kinds of contributions are welcome!
* If you wish to buy me a <a href="https://www.buymeacoffee.com/erdogant">Coffee</a> for this work, it is very appreciated :)

